@@ -1,8 +1,8 @@
-# $Id: Proxy.pm,v 1.13.2.1 2006/11/01 18:30:54 fil Exp $
+# $Id: Proxy.pm 168 2006-11-16 19:57:48Z fil $
 package POE::Component::IKC::Proxy;
 
 ##############################################################################
-# $Id: Proxy.pm,v 1.13.2.1 2006/11/01 18:30:54 fil Exp $
+# $Id: Proxy.pm 168 2006-11-16 19:57:48Z fil $
 # Copyright 1999,2002,2004 Philip Gwyn.  All rights reserved.
 # This program is free software; you can redistribute it and/or modify
 # it under the same terms as Perl itself.
@@ -21,7 +21,7 @@ use POE::Component::IKC::Specifier;
 require Exporter;
 @ISA = qw(Exporter);
 @EXPORT = qw(create_ikc_proxy);
-$VERSION = '0.1902';
+$VERSION = '0.1903';
 
 sub DEBUG { 0 }
 
@@ -164,7 +164,7 @@ L<POE>, L<POE::Component::IKC>
 =cut
 
 
-$Log: Proxy.pm,v $
+$Log$
 Revision 1.13.2.1  2006/11/01 18:30:54  fil
 Moved to version 0.1902
 
